@@ -72,6 +72,11 @@ i18n_noops[] = {
        "be used."),
     N_("Prefer S/MIME over OpenPGP if both are possible."),
 
+    /* TRANSLATORS: Part of the config dialog. */
+    N_("Configuration of GnuPG System options"),
+    /* TRANSLATORS: Part of the config dialog. */
+    N_("Configuration of debug options"),
+
     /* TRANSLATORS: Part of the config dialog. */
     N_("Search and import &X509 certificates in the configured directory services"),
     /* TRANSLATORS: Part of the config dialog. Tooltip */
@@ -88,14 +93,21 @@ i18n_noops[] = {
     /* TRANSLATORS: Included means here both attached keys and keys from the
      * headers */
     N_("Import OpenPGP keys from mail attachments or from mail headers."),
+    /* TRANSLATORS: Part of the config dialog. */
+    N_("Encrypt &drafts of secure mails to this key:"),
+    /* TRANSLATORS: Part of the config dialog. */
+    N_("Encrypt drafts and autosaved mails if the secure button is toggled."),
 
     /* Not options but strings for the key adder */
     /* TRANSLATORS: Part of address book key configuration dialog.
        The contacts name follows. */
-    N_("Configure key for:"),
+    N_("Settings for:"),
     /* TRANSLATORS: Part of address book key configuration dialog.
        An example for a public key follows. */
     N_("Paste a public key export here. It should look like:"),
+    /* TRANSLATORS: Part of address book key configuration dialog.
+       An example for a public certificate follows. */
+    _("Paste certificates here. They should look like:"),
     /* TRANSLATORS: Part of address book key configuration dialog. */
     N_("Failed to parse any public key."),
     /* TRANSLATORS: Part of address book key configuration dialog. */
@@ -116,17 +128,42 @@ i18n_noops[] = {
     N_("User Ids:"),
     /* TRANSLATORS: Part of address book key configuration dialog. %1 is
         a placeholder for the plual for key / keys. */
-    N_("You are about to configure the following %1 for:"),
+    N_("You are about to configure the following OpenPGP %1 for:"),
     /* TRANSLATORS: Part of address book key configuration dialog.
        used in a sentence as plural form. */
     N_("keys"),
     /* TRANSLATORS: Part of address book key configuration dialog.
        used in a sentence as singular form. */
     N_("key"),
+    /* TRANSLATORS: Part of address book key configuration dialog. %1 is
+        a placeholder for the plual for certificate / certificates. */
+    N_("You are about to configure the following S/MIME %1 for:"),
+    /* TRANSLATORS: Part of address book key configuration dialog.
+       used in a sentence as plural form. */
+    N_("certificates"),
+    /* TRANSLATORS: Part of address book key configuration dialog.
+       used in a sentence as singular form. */
+    N_("certificate"),
+
+    N_("This may take several minutes..."),
+    N_("Validating S/MIME certificates"),
+
     /* TRANSLATORS: Part of address book key configuration dialog. */
     N_("Continue?"),
     /* TRANSLATORS: Part of address book key configuration dialog. */
-    N_("Confirm keys"),
+    N_("Confirm"),
+    /* TRANSLATORS: Part of address book key configuration dialog. */
+    N_("Always secure mails"),
+    /* TRANSLATORS: Part of address book key configuration dialog. */
+    N_("Use these keys for this contact:"),
+
+    /* TRANSLATORS: Part of address book key configuration dialog.
+       Info box for the key configuration. */
+    N_("You can use this to override the keys "
+       "for this contact. The keys will be imported and used "
+       "regardless of their trust level."),
+    N_("For S/MIME the root certificate has to be trusted."),
+    N_("Place multiple keys in here to encrypt to all of them."),
     /* TRANSLATORS: Part of debugging configuration. */
     N_("Enable Logging"),
     N_("Default"),
