@@ -42,10 +42,9 @@
 static int
 sink_data_write (sink_t sink, const void *data, size_t datalen)
 {
-  TSTART;
   GpgME::Data *d = static_cast<GpgME::Data *>(sink->cb_data);
   d->write (data, datalen);
-  TRETURN 0;
+  return 0;
 }
 
 static int
@@ -106,10 +105,12 @@ CryptController::collect_data ()
       body = nullptr;
     }
 
-  LPMESSAGE message = get_oom_base_message (m_mail->item ());
+  LPMESSAGE message = m_mail->isCryptoMail() ?
+                      get_oom_base_message (m_mail->item ()) :
+                      get_oom_message (m_mail->item ());
   if (!message)
     {
-      log_error ("%s:%s: Failed to get base message.",
+      log_error ("%s:%s: Failed to get message.",
                  SRCNAME, __func__);
     }
 
@@ -117,9 +118,12 @@ CryptController::collect_data ()
   int n_att_usable = count_usable_attachments (att_table);
   if (!n_att_usable && !body)
     {
-      gpgol_message_box (m_mail->getWindow (),
-                         utf8_gettext ("Can't encrypt / sign an empty message."),
-                         utf8_gettext ("GpgOL"), MB_OK);
+      if (!m_mail->isDraftEncrypt())
+        {
+          gpgol_message_box (m_mail->getWindow (),
+                             utf8_gettext ("Can't encrypt / sign an empty message."),
+                             utf8_gettext ("GpgOL"), MB_OK);
+        }
       gpgol_release (message);
       mapi_release_attach_table (att_table);
       xfree (body);
@@ -428,8 +432,31 @@ int
 CryptController::resolve_keys ()
 {
   TSTART;
+
   m_recipients.clear();
 
+  if (m_mail->isDraftEncrypt() && opt.draft_key)
+    {
+      const auto key = KeyCache::instance()->getByFpr (opt.draft_key);
+      if (key.isNull())
+        {
+          const char *buf = utf8_gettext ("Failed to encrypt draft.\n\n"
+                                          "The configured encryption key for drafts "
+                                          "could not be found.\n"
+                                          "Please check your configuration or "
+                                          "turn off draft encryption in the settings.");
+          gpgol_message_box (get_active_hwnd (),
+                             buf,
+                             _("GpgOL"), MB_OK);
+          TRETURN -1;
+        }
+      log_debug ("%s:%s: resolved draft encryption key protocol is: %s",
+                 SRCNAME, __func__, to_cstr (key.protocol()));
+      m_proto = key.protocol ();
+      m_recipients.push_back (key);
+      TRETURN 0;
+    }
+
   if (!m_recipient_addrs.size())
     {
       /* Should not happen. But we add it for better bug reports. */
@@ -529,6 +556,8 @@ CryptController::resolve_keys ()
   args.push_back (std::string ("--lang"));
   args.push_back (std::string (gettext_localename ()));
 
+  bool has_smime_override = false;
+
   if (m_encrypt)
     {
       args.push_back (std::string ("--encrypt"));
@@ -536,7 +565,14 @@ CryptController::resolve_keys ()
       for (const auto &addr: m_recipient_addrs)
         {
           const auto mbox = GpgME::UserID::addrSpecFromString (addr.c_str());
-          const auto overrides = KeyCache::instance ()->getOverrides (mbox);
+          auto overrides =
+            KeyCache::instance ()->getOverrides (mbox, GpgME::OpenPGP);
+          const auto cms_overrides =
+            KeyCache::instance ()->getOverrides (mbox, GpgME::CMS);
+
+          overrides.insert(overrides.end(), cms_overrides.begin(),
+                           cms_overrides.end());
+
           if (overrides.size())
             {
               std::string overrideStr = mbox + ":";
@@ -547,6 +583,7 @@ CryptController::resolve_keys ()
                       TRACEPOINT;
                       continue;
                     }
+                  has_smime_override |= key.protocol() == GpgME::CMS;
                   overrideStr += key.primaryFingerprint();
                   overrideStr += ",";
                 }
@@ -558,6 +595,13 @@ CryptController::resolve_keys ()
         }
     }
 
+  if (!opt.prefer_smime && has_smime_override)
+    {
+      /* Prefer S/MIME if there was an S/MIME override */
+      args.push_back (std::string ("--preferred-protocol"));
+      args.push_back (std::string ("cms"));
+    }
+
   // Args are prepared. Spawn the resolver.
   auto ctx = GpgME::Context::createForEngine (GpgME::SpawnEngine);
   if (!ctx)
@@ -623,6 +667,13 @@ CryptController::do_crypto (GpgME::Error &err, std::string &r_diag)
   log_debug ("%s:%s",
              SRCNAME, __func__);
 
+  if (m_mail->isDraftEncrypt ())
+    {
+      log_debug ("%s:%s Disabling sign because of draft encrypt",
+                 SRCNAME, __func__);
+      m_sign = false;
+    }
+
   /* Start a WKS check if necessary. */
   WKSHelper::instance()->start_check (m_mail->getSender ());
 
@@ -1147,7 +1198,7 @@ CryptController::update_mail_mapi ()
   if (!rc)
     {
       rc = finalize_message (message, att_table, protocol, m_encrypt ? 1 : 0,
-                             false);
+                             false, m_mail->isDraftEncrypt (), exchange_major_version);
     }
 
   // only on error.
