@@ -440,8 +440,12 @@ public:
   int get_signature_level () const;
 
   /** Check if all attachments are hidden and show a warning
-    message appropiate to the crypto state if necessary. */
-  int checkAttachments_o () const;
+    message appropiate to the crypto state if necessary.
+
+    If silent is true it will not show a warning but silently
+    remove the bad attachments.
+    */
+  int checkAttachments_o (bool silent);
 
   /** Check if the mail should be encrypted "inline" */
   bool getDoPGPInline () const {return m_do_inline;}
@@ -629,10 +633,19 @@ public:
   void setDecryptAgain (bool value) { m_decrypt_again = value; }
   bool isDecryptAgain () const { return m_decrypt_again; }
 
+  /* The type of the message. */
   msgtype_t msgtype () const { return m_type; }
 
-private:
+  /* The mail was loaded after we have seen a BeforePrint event. */
+  void setIsPrint (bool value) { m_printing = value; }
+  bool isPrint () const { return m_printing; }
+
+  /* Update the catgories (encrypted / trust in) based on the
+     crypt results. */
   void updateCategories_o ();
+
+private:
+  bool checkIfMailIsChildOfPrintMail_o ();
   void updateSigstate ();
 
   LPDISPATCH m_mailitem;
@@ -688,5 +701,6 @@ private:
   bool m_is_draft_encrypt; /* Mail is a draft that should be encrypted */
   bool m_decrypt_again; /* Mail should be decrypted again if it sees
                            another beforeread */
+  bool m_printing; /* Mail is decrypted for printing */
 };
 #endif // MAIL_H
