@@ -71,6 +71,8 @@ DEFINE_GUID(IID_FolderEvents, 0x000630F7, 0x0000, 0x0000,
             0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46);
 DEFINE_GUID(IID_ApplicationEvents, 0x0006304E, 0x0000, 0x0000,
             0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46);
+DEFINE_GUID(IID_ApplicationEvents_11, 0x0006302C, 0x0000, 0x0000,
+            0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46);
 DEFINE_GUID(IID_ExplorerEvents, 0x0006300F, 0x0000, 0x0000,
             0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46);
 DEFINE_GUID(IID_ExplorersEvents, 0x00063078, 0x0000, 0x0000,
@@ -433,4 +435,8 @@ bool is_junk_mail (LPDISPATCH mailitem);
 
 /* Return true if this message is in the draft folder for this account */
 bool is_draft_mail (LPDISPATCH mailitem);
+
+/* Returns info about a dispparms variable for debugging. */
+void format_variant (std::istringstream &stream, VARIANT *var);
+std::string format_dispparams (DISPPARAMS *p);
 #endif /*OOMHELP_H*/
